![westat logo](https://github.com/stat-fit/westat/blob/main/static/logo.jpg)

## Author: statfit@hotmail.com

### Description 
Westat is a part of pyminer project. 

A package for stat and data miner,calculate woe and iv,and plot woe ,plot iv,calculate ks ,plot ks and auc,plot roc


This is a simple stat package. You can see more from 
[GitHub](https://github.com/stat-fit/westat).
Or 
[PyPI](https://pypi.org/project/westat/).

[pyminer](http://www.pyminer.com).


#### install

```bash
pip install westat
```

#### version
```bash
import westat
westat.version
```

### AUC and KS
<p></p>

<img src="static/auc_ks.png" width = "1024" height = "500" alt="auc_ks" align=center />

<p></p>

### decision tree cut bins
<p></p>
<img src="https://github.com/stat-fit/westat/blob/main/static/tree_iv.png" width = "1024" height = "500" alt="tree_iv" align=center />
<img src="static/view_woe_iv.png" width = "1024" height = "500" alt="view_woe_iv" align=center />

<p></p>


### qcut bins
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/qcut_woe_iv.png" width = "1024" height = "500" alt="qcut_woe_iv" align=center />

<p></p>

### custom bins
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/cut_woe_iv.png" width = "1024" height = "500" alt="cut_woe_iv" align=center />

<p></p>

### Lift
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/get_lift.png" width = "1024" height = "500" alt="get_lift" align=center />

<p></p>

### PSI
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/get_psi.png" width = "1024" height = "500" alt="get_psi" align=center />

<p></p>

### scorecard
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/get_scorecard.png" width = "1024" height = "500" alt="get_scorecard" align=center />

<p></p>

### predict
<p></p>

<img src="https://github.com/stat-fit/westat/blob/main/static/predict_score.png" width = "1024" height = "500" alt="predict_score" align=center />

<p></p>